# Instructions
**Instructions are not questions or conversations, use the Chat for those!**

The Instructions feature is designed to allow users to provide specific instructions or tasks to a selected agent. The Agent will choose to run commands from its list of available commands (if any) to complete whatever task was given to it in the instructions.

## Smart Instructions
Smart Instructions will take your request, do research online to find the most up to date information about its task so that it has information in memory. It will then use this information to complete the task you asked it to do along with executing any commands necessary along the way.